@@ -2,14 +2,14 @@ package Baseobject;
 
 use strict ;
 use Cwd;
-use Trailer;
 use Carp qw (cluck carp);
+use Data::Dumper;
 
 require      Exporter;
 our @ISA = qw (Exporter);
 our @EXPORT = qw (baseconfigure verbosity freezeverbosity);
 
-our $VERSION = "1.18";
+our $VERSION = "1.19";
 
 $Baseobject::directfeedback=0; # for downward compatibility
 $Baseobject::quickdeath=0;
@@ -133,7 +133,8 @@ sub error
   else
   {
     my ($package,$file,$line)=caller;
-    return "$package: ",$self->{error};
+    my $ret = "$package:$file:$line ". $self->{error};
+	return $ret;
   }
 }
 
@@ -277,13 +278,10 @@ sub checkneeds
 }
 
 
-sub inspect
-{
-
+sub inspect {
   my $self=shift;
-  my $Trailer=new Trailer();
-  my $string = $Trailer->ascarray(@_);
-  my ($package,$file,$line)=caller;
+  my $string = Dumper(@_);
+  my ($package, $file, $line) = caller;
   $string.= " Inspect called at: $file line $line\n";
 }
 
@@ -537,8 +535,7 @@ use FileHandle;
 our @ISA=('Baseobject' );
 our @EXPORT = qw (verbosity);
 
-sub new
-{
+sub new {
 	#
 	# configfile should contain lines with format:
 	# key=value[ ,value1, value2, ... ]
@@ -576,10 +573,10 @@ sub new
 
 	$self->fields(@_);
 
-	return $self if ($self->error());
-	$configfile=$self->{fields}->{configfile};
-	$configfile="$self->{SYSCONFDIR}/$configfile" unless ($configfile =~ /\//);
-	$self->debug( "Readconfig: using configfile: $self->{fields}->{configfile}");
+	return $self if $self->error();
+	$configfile = $self->{fields}->{configfile};
+	$configfile = "$self->{SYSCONFDIR}/$configfile" unless ($configfile =~ /\//);
+	$self->debug("Readconfig: using configfile: $self->{fields}->{configfile}");
 
 	#sorry english or dutch only
 	$self->{fields}->{language} = 'en' if ($self->{fields}->{language} ne 'nl');
@@ -587,13 +584,9 @@ sub new
 	my $cf={};
 	$self->field('cf',$cf);
 
-	my $conf=new FileHandle();
-
-	if ($self->{fields}->{secret})
-	{
-		my $mode= (stat $configfile)[2];
-		unless ($mode)
-		{
+	if ($self->{fields}->{secret}) {
+		my $mode = (stat $configfile)[2];
+		unless ($mode) {
 			$self->error( "Could not stat file: \"$configfile\", $!" );
 			return $self;
 		}
@@ -601,23 +594,14 @@ sub new
 		my $realmode=sprintf "%04o",($mode & 07777);
 		my $gomode  =sprintf "%04o",($mode & 00037);
 		$gomode =~ s/0//g;
-		if ($gomode)
-		{
+		if ($gomode) {
 			$self->error( "ERROR filepermissions too permissive for file $configfile current permissions: $realmode\n");
 			return $self;
 		}
 	}
 
-#
-# stringio
-#	open(my $fh = new IO::File, '+<', \my $string);
-
-# temporary file
-#	open(my $fh = new IO::File, '+>', undef);
-
-#  Fixme!
-	$conf = new IO::File($configfile, '<:utf8');
-	unless ($conf)	{
+	my $conf = new IO::File($configfile, '<:utf8');
+	unless ($conf) {
 		$self->error("Could not read config file: $configfile $!\n");
 		unless ( -r $configfile ) {
 			my $filename= $configfile;
@@ -644,17 +628,15 @@ sub new
 		$currentlanguage="_$self->{fields}->{language}";
 	}
 
-	while(<$conf>)
-	{
+	while(<$conf>) {
 		chomp;
 		# skip commented lines and empty lines
-		next if (/^\s*\#/); next if (/^\s*$/);
+		next if (/^\s*\#/); next if /^\s*$/;
 
 		#remove commented part of the line
 #    s/\#.*//;
 
-		if (/^\S/)
-		{
+		if (/^\S/) {
 			# something on the first column MUST BE A KEY
 			#if values contains a '=', don't split it further, by limit of 2
 			($key,$value)=split '=',$_,2 ;
@@ -662,59 +644,43 @@ sub new
 			$key =~ s/^\s*//; $key =~ s/\s*$//;
 			#do wo expect this one?
 			my $expected=0;
-			foreach my $el  (@{$self->{fields}->{needs}},@{$self->{fields}->{allows}} )
-			{
+			foreach my $el (@{$self->{fields}->{needs}},@{$self->{fields}->{allows}} ) {
 				$expected++ if ( $key=~/^$el$/);
-				if ($language)
-				{
-					$expected++ if ( $key=~/^$el$language$/);
+				if ($language) {
+					$expected++ if ($key=~/^$el$language$/);
 				}
-
-			}
-			unless ($expected)
-			{
+			} unless ($expected) {
 				carp "WARNING: Illegal key: \"$key\" in configfile: $configfile, line $.\n$_\n";
 				next;
 			}
-		}
-		else
-		{
-			$value=$_;
+		} else {
+			$value = $_;
 		}
 
-		if (defined ($value))
-		{
+		if (defined ($value)) {
 #      warn "value: \"$value\"";
 			# remove leading trailing spaces
 			$value=~s/^\s*//; $value=~ s/\s*$//;
 			push (@{$cf->{$key}},$value) ;
 		}
 	}
-	close $conf;
+	$conf->close;
 
 	my @missing;
-	foreach my $key (@{$self->{fields}->{'needs'}})
-	{
-
-		unless ($language)
-		{
+	foreach my $key (@{$self->{fields}->{'needs'}}) {
+		unless ($language) {
 			push (@missing, $key) unless (exists ($cf->{$key}));
-		}
-		else
-		{
+		} else {
 			push (@missing, $key) unless (exists ($cf->{$key.$currentlanguage}) or
 										  exists ($cf->{$key}));
-
 		}
 
 	}
-	if (@missing)
-	{
+	if (@missing) {
 #    warn $self->inspect($cf);
 		$self->error("ERROR: Missing required key(s) in configfile: $configfile\n\"",join ('" "',@missing),"\"\n");
 	}
 	return $self;
-
 }
 
 sub value
